@@ -8,9 +8,11 @@ Created on Mon Sep 21 11:29:27 2020
 import pyvisa
 from time import sleep
 
+name = "MaiTai"
+hwid = ["10C4:EA60"]
+serial_number = ["0001"]
 
-
-class MaiTai:
+class instrument:
 
     def __init__(self,port):
         rm = pyvisa.ResourceManager()
