@@ -11,9 +11,9 @@ import numpy as np
 
 rm = pyvisa.ResourceManager()
 name = "PowerMeter"
+hwid = ["0403:6011"]
 
-
-class PowerMeter:
+class instrument:
     def __init__(self,port):
 
         self.Pmeter = rm.open_resource(f'ASRL/{port.name}::INSTR')
