@@ -9,8 +9,8 @@ class instrument:
         pass
 
     def get_frame(self, exp_time):
-        x = (self.x2 - self.x1) / self.xbin
-        y = (self.y2 - self.y1) / self.ybin
+        x = int((self.x2 - self.x1) / self.xbin)
+        y = int((self.y2 - self.y1) / self.ybin)
         return np.random.rand(x, y)
 
     def roi(self, x1, x2, y1, y2):
